// Need G4P library
import g4p_controls.*;
import processing.serial.*;
// You can remove the PeasyCam import if you are not using
// the GViewPeasyCam control or the PeasyCam library.
int tlength = 10;
int vrange = 1024;
int vzero = 0;
 
Serial myPort;        // The serial port
float inByte = 0;

float xPos = 50;         // horizontal position of the graph
float height_old = 0;
float height_new = 0;

int savedTime = millis();
int readTime = savedTime;

int xwidth = 1000;
int yheight = 500;
int wframe = 50;

Table dtable;
Boolean recordOn = false;
String FileName;

public void setup(){
  size(1100, 600, JAVA2D);
  createGUI();
  customGUI();
  
  // List all the available serial ports
  println(Serial.list());
  // Open whatever port is the one you're using.
  myPort = new Serial(this, Serial.list()[1], 9600); //CHANGE If necessary
  // don't generate a serialEvent() unless you get a newline character:
  myPort.bufferUntil('\n');
  // set inital background:
  background(255);
  
  dtable = new Table();
  
  dtable.addColumn("time");
  dtable.addColumn("value");
  label1.setText("Record OFF");
  
}

public void draw(){ 
    createaxes();
  
   //Map and draw the line for new data point ____________________________________
     // println(inByte);
     if (inByte > vrange) {  
      inByte = vrange;   //...set the color to black
     }
     inByte = map(inByte, 0, vrange, 0, yheight);
     // inByte=random(1000);
     
     if (readTime > tlength*1000) {  
      if (recordOn)
      {
        FileName = "Pr"+year()+month()+day()+hour()+minute()+second()+".csv";
        label1.setText(FileName);
        saveTable(dtable, FileName);
        dtable.clearRows();
        recordOn = false;
      }
      readTime = 0;
      savedTime = millis();
      background(255);  
     }
     
     xPos = map(readTime, 0, tlength*1000, wframe, xwidth+wframe);
     
     height_new = wframe+yheight - inByte; 
     line(xPos - 1, height_old, xPos, height_new);
     height_old = height_new;
}

// Use this method to add additional statements
// to customise the GUI controls
public void customGUI(){

}

public void createaxes(){ // Create and draw axes _____________________________________________________________________________-
  
  // Create axes
  
  //background(255);
  
  fill(255);
  stroke(255);
  rect(0,0,xwidth+2*wframe,wframe);
  rect(0,0,wframe,yheight+2*wframe);
  rect(0,yheight+wframe, xwidth+2*wframe,wframe);
  stroke(0);
  strokeWeight(2);
  //background(255);
  line(wframe-2, wframe, wframe-2, wframe+yheight);
  line(wframe, yheight+wframe+2, wframe+xwidth,  yheight+wframe+2);
  
  int dx = xwidth/10;
  for (int i=0; i<11; i++) {
    float dxx = dx*i;
    float x = wframe + dxx;
    stroke(0, 0, 0);
    line(x, yheight+wframe+2, x, yheight+wframe+8);
    fill(0);
    textAlign(CENTER, CENTER);
    float num = tlength;
    num= num/10;
    num=i*num;
    String snum = nf(num, 0, 1);
    text(snum, x, yheight+wframe+16);
  }
  int dy = yheight/4;
  for (int i=0; i<5; i++) {
    float dyy = dy*i;
    float y = yheight+wframe - dyy;
    line(wframe-2, y, wframe-8, y);
    
    textAlign(RIGHT, CENTER);
    float num = vrange;
    num= vrange/4;
    num=i*num;
    String snum = nf(num, 0, 0);
    text(snum, 40, y-2);
  }
  // End create axes
}

void serialEvent (Serial myPort) // Serial event _______________________________________________________________________________________________________________
{
  // get the ASCII string:
  String inString = myPort.readStringUntil('\n');
  readTime=millis() - savedTime;
  
  if (inString != null) 
  {
    // trim off any whitespace:
    inString = trim(inString);
    if (recordOn)
    {
       TableRow newRow = dtable.addRow();
       newRow.setInt("time", readTime);
       newRow.setString("value", inString);
    }
    inByte = float(inString);
    inByte = inByte - vzero;
  }
}
